summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-02-07 22:42:58 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-02-07 22:52:08 -0600
commite00ed36d71fc201560a9ae8b5efb6dbbaa5728d8 (patch)
treeb839e719e2974f2934e462def64ae6721f82487b /png.h
parentc40df89cef39c29d1a0d833cc6f4e8d3004271b8 (diff)
downloadlibpng-e00ed36d71fc201560a9ae8b5efb6dbbaa5728d8.tar.gz
[devel] Imported from libpng-1.5.0beta02.tarv1.5.0beta02
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index de8b7a9ea..3dac46ea1 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.0beta01 - February 8, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.0beta01 - February 8, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -137,7 +137,7 @@
* 1.4.1beta01-03 14 10401 14.so.14.1[.0]
* 1.4.1rc01 14 10401 14.so.14.1[.0]
* 1.4.1beta04-09 14 10401 14.so.14.1[.0]
- * 1.5.0beta01 15 10500 15.so.15.0[.0]
+ * 1.5.0beta01-02 15 10500 15.so.15.0[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -169,7 +169,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.0beta01, February 8, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -287,7 +287,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.0beta01 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -343,9 +343,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.0beta01"
+#define PNG_LIBPNG_VER_STRING "1.5.0beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.0beta01 - February 8, 2010\n"
+ " libpng version 1.5.0beta02 - February 8, 2010\n"
#define PNG_LIBPNG_VER_SONUM 14
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -358,7 +358,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -795,7 +795,7 @@ typedef struct { ; } png_struct_def;
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_5_0beta01;
+typedef png_structp version_1_5_0beta02;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.0beta01 - February 8, 2010
+ * libpng version 1.5.0beta02 - February 8, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.0beta01 - February 8, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.0beta02 - February 8, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -169,7 +169,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta01, February 8, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta02, February 8, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -287,7 +287,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.0beta01 are Y2K compliant. It is my belief that earlier
+ * upward through 1.5.0beta02 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*